Auton Universal Viewer
======================

Welcome to the source code for Auton Universal Viewer (AUViewer). AUViewer is
a tool for viewing, analyzing, and annotating large time-series datasets
by an individual analyst (standalone) or a team of analysts/domain experts
(as a browser-based application which remains performant on limited bandwidth).

Documentation & Support
-----------------------

Documentation is available at
readthedocs_.

Discussion & peer-support is available on the auviewer-users_ group.

.. _readthedocs: https://auviewer.readthedocs.io/
.. _auviewer-users: https://groups.google.com/g/auviewer-users

Installation
------------

To install::

    pip install auviewer

*Requires Python 3.8*

License
-------

Auton Universal Viewer is shared under the MIT license, available in the
LICENSE file.
